@@ -1,7 +1,9 @@
 use strict;
 use warnings;
 
-package Apache2::Dummy::RequestRec 0.02;
+package Apache2::Dummy::RequestRec;
+
+our $VERSION = '0.03';
 
 use Apache2::Const -compile => qw(OK DECLINED M_GET M_POST M_OPTIONS);
 use APR::Table;
